// Author: Fabrice Marguerie
// http://weblogs.asp.net/fmarguerie/
// fabrice@madgeek.com
//
// Free for use

#region Imports
using System;
using System.ComponentModel;
using System.IO;
using System.Reflection;
using System.Resources;
using System.Text;
using System.Web.UI;
using System.Web.UI.WebControls;
#endregion

// set tag prefix for controls. This is used by the designer.
//[assembly: TagPrefix("Madgeek.Web.UI.WebControls", "mad")]

namespace Madgeek.Web.UI.WebControls
{
  /// <summary>
	/// Panel which borders are styled with CSS.
	/// </summary>
  [ToolboxData("<{0}:StyledPanel runat=\"server\" Width=\"500\" Height=\"100\">StyledPanel</{0}:StyledPanel>")]
  //[Designer(typeof(StyledPanelDesigner))]
  public class StyledPanel : System.Web.UI.WebControls.Panel
	{
    /// <summary>
    /// Resource base name.
    /// </summary>
    /// <remarks>This is actually the file name of the resource file without the extension.</remarks>
    private const string ResourceBaseName = "HtmlTemplates";

		private string _CssSuffix;

		[Bindable(true), Category("Appearance"), DefaultValue("")]
		public string CssSuffix
		{
			get
			{
				return _CssSuffix;
			}

			set
			{
				_CssSuffix = value;
			}
		}

    /// <summary>
    /// Generates a string from a collection of attributes.
    /// </summary>
    /// <param name="attributes"></param>
    /// <returns></returns>
    protected string RenderAttributesAsString(System.Web.UI.AttributeCollection attributes)
    {
      HtmlTextWriter	htmlTextWriter;

      if (attributes.Count < 1)
        return "";
      using (TextWriter textWriter = new StringWriter())
      {
        htmlTextWriter = new HtmlTextWriter(textWriter);
        attributes.Render(htmlTextWriter);
        return textWriter.ToString();
      }
    }
    
    /// <summary>
		/// Render this control to the output parameter specified.
		/// </summary>
		/// <param name="output"> The HTML writer to write out to </param>
		protected override void Render(HtmlTextWriter output)
		{
      string          attributes;
      string          html;
      ResourceManager	resourceManager;
      string          template;

      resourceManager = new ResourceManager(typeof(StyledPanel).Assembly.GetName().Name+"."+ResourceBaseName,
        Assembly.GetExecutingAssembly());

      // Begin
      template = resourceManager.GetString("StyledPanel_Begin");
      attributes = RenderAttributesAsString(Attributes);
      html = String.Format(template,
        new object[] {UniqueID, attributes, Width, Height, _CssSuffix});
      output.Write(html);

      // Sub controls
      foreach (Control control in this.Controls)
        control.RenderControl(output);

      // End
      template = resourceManager.GetString("StyledPanel_End");
      html = String.Format(template,
        new object[] {UniqueID, attributes, Width, Height, _CssSuffix});
      output.Write(html);
    }
	}

  /*
  /// <summary>
  /// Extends design-time behavior for the <see cref="StyledPanel"/> Web server control.
  /// </summary>
  public class StyledPanelDesigner : System.Web.UI.Design.WebControls.PanelDesigner
  {
    /// <summary>
    /// Initializes a new instance of the <see cref="StyledPanelDesigner"/> class.
    /// </summary>
    public StyledPanelDesigner() : base()
    {
    }
  }
  */
}